@@ -1,4 +1,8 @@
 test_that("Merge all DESCRIPTION files with CITATION_basic", {
+  rvers <- getRversion()
+  skip_if(rvers <= "4.4.1", "Snapshot created with R 4.5.0")
+  skip_on_cran()
+
   allfiles <- list.files(
     system.file("examples", package = "cffr"),
     pattern = "^DESC", full.names = TRUE
